@@ -1,13 +1,13 @@
 from themispy.scrapy.items import FileDownloader
 from themispy.scrapy.pipelines import (AzureBlobUploadPipeline,
                                        AzureFileDownloaderPipeline)
-from themispy.scrapy.readers import read_jsonl
+from themispy.scrapy.readers import read_jsonlines_blob
 from themispy.scrapy.spiders import run_spider
 
 __all__ = [
     "FileDownloader",
     "AzureBlobUploadPipeline",
     "AzureFileDownloaderPipeline",
-    "read_jsonl",
+    "read_jsonlines_blob",
     "run_spider"
 ]
